@@ -22,19 +22,19 @@
 
 #include <QPointer>
 
+#include "torrentcontrol.h"
 #include <diskio/chunkmanager.h>
 #include <diskio/piecedata.h>
-#include <util/timer.h>
 #include <download/streamingchunkselector.h>
-#include "torrentcontrol.h"
+#include <util/timer.h>
 
 namespace bt
 {
 class TorrentFileStream::Private
 {
 public:
-    Private(TorrentControl* tc, ChunkManager* cman, bool streaming_mode, TorrentFileStream* p);
-    Private(TorrentControl* tc, Uint32 file_index, ChunkManager* cman, bool streaming_mode, TorrentFileStream* p);
+    Private(TorrentControl *tc, ChunkManager *cman, bool streaming_mode, TorrentFileStream *p);
+    Private(TorrentControl *tc, Uint32 file_index, ChunkManager *cman, bool streaming_mode, TorrentFileStream *p);
     ~Private();
 
     void reset();
@@ -43,15 +43,15 @@ public:
     Uint32 firstChunk();
     Uint32 firstChunkOffset();
     Uint32 lastChunkSize();
-    qint64 readData(char* data, qint64 maxlen);
-    qint64 readCurrentChunk(char* data, qint64 maxlen);
+    qint64 readData(char *data, qint64 maxlen);
+    qint64 readCurrentChunk(char *data, qint64 maxlen);
     bool seek(qint64 pos);
 
 public:
     QPointer<TorrentControl> tc;
     Uint32 file_index;
-    ChunkManager* cman;
-    TorrentFileStream* p;
+    ChunkManager *cman;
+    TorrentFileStream *p;
     Uint64 current_byte_offset;
     Uint64 bytes_readable;
     bool opened;
@@ -60,29 +60,29 @@ public:
     Uint32 current_chunk;
     Uint32 current_chunk_offset;
     bt::Timer timer;
-    StreamingChunkSelector* csel;
+    StreamingChunkSelector *csel;
 
     BitSet bitset;
 };
 
-
-TorrentFileStream::TorrentFileStream(TorrentControl* tc, ChunkManager* cman, bool streaming_mode, QObject* parent)
-    : QIODevice(parent), d(new Private(tc, cman, streaming_mode, this))
+TorrentFileStream::TorrentFileStream(TorrentControl *tc, ChunkManager *cman, bool streaming_mode, QObject *parent)
+    : QIODevice(parent)
+    , d(new Private(tc, cman, streaming_mode, this))
 {
 }
 
-TorrentFileStream::TorrentFileStream(TorrentControl* tc, Uint32 file_index, ChunkManager* cman, bool streaming_mode, QObject* parent)
-    : QIODevice(parent), d(new Private(tc, file_index, cman, streaming_mode, this))
+TorrentFileStream::TorrentFileStream(TorrentControl *tc, Uint32 file_index, ChunkManager *cman, bool streaming_mode, QObject *parent)
+    : QIODevice(parent)
+    , d(new Private(tc, file_index, cman, streaming_mode, this))
 {
 }
 
-
 TorrentFileStream::~TorrentFileStream()
 {
     delete d;
 }
 
-const bt::BitSet& TorrentFileStream::chunksBitSet() const
+const bt::BitSet &TorrentFileStream::chunksBitSet() const
 {
     return d->bitset;
 }
@@ -92,14 +92,14 @@ Uint32 TorrentFileStream::currentChunk() const
     return d->current_chunk - d->firstChunk();
 }
 
-qint64 TorrentFileStream::writeData(const char* data, qint64 len)
+qint64 TorrentFileStream::writeData(const char *data, qint64 len)
 {
     Q_UNUSED(data);
     Q_UNUSED(len);
     return -1;
 }
 
-qint64 TorrentFileStream::readData(char* data, qint64 maxlen)
+qint64 TorrentFileStream::readData(char *data, qint64 maxlen)
 {
     return d->readData(data, maxlen);
 }
@@ -177,7 +177,7 @@ QString TorrentFileStream::path() const
     }
 }
 
-void TorrentFileStream::chunkDownloaded(TorrentInterface* tc, Uint32 chunk)
+void TorrentFileStream::chunkDownloaded(TorrentInterface *tc, Uint32 chunk)
 {
     Q_UNUSED(tc);
     Q_UNUSED(chunk);
@@ -190,15 +190,18 @@ void TorrentFileStream::emitReadChannelFinished()
     Q_EMIT readChannelFinished();
 }
 
-
 //////////////////////////////////////////////////
-TorrentFileStream::Private::Private(TorrentControl* tc,
-                                    ChunkManager* cman,
-                                    bool streaming_mode,
-                                    TorrentFileStream* p)
-    : tc(tc), file_index(0), cman(cman), p(p),
-      current_byte_offset(0), bytes_readable(0), opened(false),
-      current_chunk_offset(0), csel(0), bitset(cman->getNumChunks())
+TorrentFileStream::Private::Private(TorrentControl *tc, ChunkManager *cman, bool streaming_mode, TorrentFileStream *p)
+    : tc(tc)
+    , file_index(0)
+    , cman(cman)
+    , p(p)
+    , current_byte_offset(0)
+    , bytes_readable(0)
+    , opened(false)
+    , current_chunk_offset(0)
+    , csel(0)
+    , bitset(cman->getNumChunks())
 {
     current_chunk = firstChunk();
     connect(tc, &TorrentControl::chunkDownloaded, p, &TorrentFileStream::chunkDownloaded);
@@ -210,14 +213,16 @@ TorrentFileStream::Private::Private(TorrentControl* tc,
     }
 }
 
-TorrentFileStream::Private::Private(TorrentControl* tc,
-                                    Uint32 file_index,
-                                    ChunkManager* cman,
-                                    bool streaming_mode,
-                                    TorrentFileStream* p)
-    : tc(tc), file_index(file_index), cman(cman), p(p),
-      current_byte_offset(0), bytes_readable(0), opened(false),
-      current_chunk_offset(0), csel(0)
+TorrentFileStream::Private::Private(TorrentControl *tc, Uint32 file_index, ChunkManager *cman, bool streaming_mode, TorrentFileStream *p)
+    : tc(tc)
+    , file_index(file_index)
+    , cman(cman)
+    , p(p)
+    , current_byte_offset(0)
+    , bytes_readable(0)
+    , opened(false)
+    , current_chunk_offset(0)
+    , csel(0)
 {
     current_chunk = firstChunk();
     current_chunk_offset = firstChunkOffset();
@@ -249,7 +254,7 @@ void TorrentFileStream::Private::reset()
 
 void TorrentFileStream::Private::update()
 {
-    const BitSet & chunks = cman->getBitSet();
+    const BitSet &chunks = cman->getBitSet();
     // Update the current limit
     bt::Uint32 first = firstChunk();
     bt::Uint32 last = lastChunk();
@@ -351,8 +356,7 @@ bool TorrentFileStream::Private::seek(qint64 pos)
     return true;
 }
 
-
-qint64 TorrentFileStream::Private::readData(char* data, qint64 maxlen)
+qint64 TorrentFileStream::Private::readData(char *data, qint64 maxlen)
 {
     if (!tc)
         return 0;
@@ -384,13 +388,13 @@ qint64 TorrentFileStream::Private::readData(char* data, qint64 maxlen)
     return bytes_read;
 }
 
-qint64 TorrentFileStream::Private::readCurrentChunk(char* data, qint64 maxlen)
+qint64 TorrentFileStream::Private::readCurrentChunk(char *data, qint64 maxlen)
 {
     if (!tc)
         return 0;
 
-    //Out(SYS_GEN|LOG_DEBUG) << "readCurrentChunk s " << current_chunk << " " << current_chunk_offset << endl;
-    Chunk* c = cman->getChunk(current_chunk);
+    // Out(SYS_GEN|LOG_DEBUG) << "readCurrentChunk s " << current_chunk << " " << current_chunk_offset << endl;
+    Chunk *c = cman->getChunk(current_chunk);
     // First make sure we have the chunk
     if (!current_chunk_data)
         current_chunk_data = c->getPiece(0, c->getSize(), true);
@@ -403,10 +407,10 @@ qint64 TorrentFileStream::Private::readCurrentChunk(char* data, qint64 maxlen)
     if (allowed > maxlen)
         allowed = maxlen;
 
-    //Out(SYS_GEN|LOG_DEBUG) << "readCurrentChunk r " << allowed << endl;
+    // Out(SYS_GEN|LOG_DEBUG) << "readCurrentChunk r " << allowed << endl;
 
     // Copy data
-    current_chunk_data->read((bt::Uint8*)data, allowed, current_chunk_offset);
+    current_chunk_data->read((bt::Uint8 *)data, allowed, current_chunk_offset);
 
     // Update internal state
     current_byte_offset += allowed;
@@ -420,7 +424,7 @@ qint64 TorrentFileStream::Private::readCurrentChunk(char* data, qint64 maxlen)
             csel->setCursor(current_chunk);
     }
 
-    //Out(SYS_GEN|LOG_DEBUG) << "readCurrentChunk f " << current_chunk << " " << current_chunk_offset << endl;
+    // Out(SYS_GEN|LOG_DEBUG) << "readCurrentChunk f " << current_chunk << " " << current_chunk_offset << endl;
     return allowed;
 }
 
